# Technology Obsolescence Risk Statuses and Views in Reports
### On this page
  * [Obsolescence Risk Statuses of IT Components](https://help.sap.com/docs/leanix/ea/technology-obsolescence-risk-statuses-and-views-in-reports#obsolescence-risk-statuses-of-it-components)
  * [Obsolescence Risk View Aggregation at the Application Level](https://help.sap.com/docs/leanix/ea/technology-obsolescence-risk-statuses-and-views-in-reports#obsolescence-risk-view-aggregation-at-the-application-level)
  * [Obsolescence Risk Views](https://help.sap.com/docs/leanix/ea/technology-obsolescence-risk-statuses-and-views-in-reports#obsolescence-risk-views)
  * [Missing Data Percentage](https://help.sap.com/docs/leanix/ea/technology-obsolescence-risk-statuses-and-views-in-reports#missing-data-percentage)
  * [Mitigated Risk Percentage](https://help.sap.com/docs/leanix/ea/technology-obsolescence-risk-statuses-and-views-in-reports#mitigated-risk-percentage)
  * [Unaddressed Risk Percentage](https://help.sap.com/docs/leanix/ea/technology-obsolescence-risk-statuses-and-views-in-reports#unaddressed-risk-percentage)


Learn how risk statuses are determined for IT components and applications and understand reporting views, such as Missing Data Percentage, Mitigated Risk Percentage, and Unaddressed Risk Percentage.
